@@ -28,7 +28,7 @@ class PDF::Annot::Link
     has PDF::Action::URI $.PA is entry(:alias<uri-action>);   # (Optional; PDF 1.3) A URI action
     has Numeric @.QuadPoints is entry; # (Optional; PDF 1.6) An array of 8 × n numbers specifying the coordinates of nquadrilaterals in default user space that comprise the region in which the link should be activated. The coordinates for each quadrilateral are given in the order: x1 y1 x2 y2 x3 y3 x4 y4, specifying the four vertices of the quadrilateral in counterclockwise order.
 
-    has PDF::Border $.BS is entry; # (Optional; PDF 1.6) A border style dictionary specifying the line width and dash pattern to be used in drawing the annotation’s border. The annotation dictionary’s AP entry, if present, takes precedence over the BS entry
+    has PDF::Border $.BS is entry(:alias<border-style>); # (Optional; PDF 1.6) A border style dictionary specifying the line width and dash pattern to be used in drawing the annotation’s border. The annotation dictionary’s AP entry, if present, takes precedence over the BS entry
 
     method cb-check {
         die "A Link should not have both /A and Dest entries"
