@@ -33,7 +33,7 @@ class PDF::Catalog
     use PDF::Bead-Thread; # Declares PDF::Bead & PDF::Thread
     use PDF::Class::Util :to-roman, :alpha-number, :decimal-number;
 
-    has PDF::COS::Name $.Type is entry(:required) where 'Catalog';
+    has PDF::COS::Name $.Type is entry(:required, :alias<type>) where 'Catalog';
 
     has PDF::COS::Name $.Version is entry;               # (Optional; PDF 1.4) The version of the PDF specification to which the document conforms (for example, 1.4)
     has Hash $.Extensions is entry;
@@ -76,7 +76,7 @@ class PDF::Catalog
         }
 
         #| page indices, starting at zero
-        method AT-POS(Int(Cool) $page-idx) {
+        method AT-POS(Int() $page-idx) {
             my Pair $num = $.nums.grep(*.key <= $page-idx).tail;
             my UInt $base  = $num.key;
             my PageLabelNode $props = $num.value;
